@@ -23,12 +23,12 @@
 #include "element-editor.h"
 
 #include <libanjuta/anjuta-plugin.h>
-
-#include <glib/gstrfuncs.h>
+#include <stdlib.h>
+#include <glib.h>
 
 #include <ctype.h>
 
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-class-gen-plugin.glade"
+#define BUILDER_FILE PACKAGE_DATA_DIR"/glade/anjuta-class-gen-plugin.ui"
 
 #define CC_HEADER_TEMPLATE PACKAGE_DATA_DIR"/class-templates/cc-header.tpl"
 #define CC_SOURCE_TEMPLATE PACKAGE_DATA_DIR"/class-templates/cc-source.tpl"
@@ -39,7 +39,7 @@
 typedef struct _CgWindowPrivate CgWindowPrivate;
 struct _CgWindowPrivate
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	GtkWidget *window;
 	
 	CgElementEditor *editor_cc;
@@ -61,7 +61,7 @@ enum {
 	PROP_0,
 
 	/* Construct only */
-	PROP_GLADE_XML
+	PROP_BUILDER_XML
 };
 
 static GObjectClass *parent_class = NULL;
@@ -91,7 +91,7 @@ static const gchar *GO_SCOPE_LIST[] =
 
 static const gchar *GO_PARAMSPEC_LIST[] =
 {
-	"Guess from type",
+	N_("Guess from type"),
 	"g_param_spec_object",
 	"g_param_spec_pointer",
 	"g_param_spec_enum",
@@ -171,7 +171,7 @@ cg_window_fetch_string (CgWindow *window,
 	CgWindowPrivate *priv;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	widget = glade_xml_get_widget (priv->gxml, id);
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->bxml, id));
 
 	g_return_val_if_fail (widget != NULL, NULL);
 
@@ -191,7 +191,7 @@ cg_window_fetch_integer (CgWindow *window,
 	CgWindowPrivate *priv;
 	
 	priv = CG_WINDOW_PRIVATE(window);
-	widget = glade_xml_get_widget(priv->gxml, id);
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->bxml, id));
 	
 	g_return_val_if_fail(widget != NULL, 0);
 	
@@ -213,7 +213,7 @@ cg_window_fetch_boolean (CgWindow *window,
 	CgWindowPrivate *priv;
 	
 	priv = CG_WINDOW_PRIVATE (window);
-	widget = glade_xml_get_widget (priv->gxml, id);
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->bxml, id));
 	
 	g_return_val_if_fail (widget != NULL, FALSE);
 	
@@ -225,7 +225,7 @@ cg_window_fetch_boolean (CgWindow *window,
 
 static void
 cg_window_set_heap_value (CgWindow *window,
-                          NPWValueHeap *values,
+                          GHashTable *values,
                           GType type,
                           const gchar *name,
                           const gchar *id)
@@ -242,16 +242,16 @@ cg_window_set_heap_value (CgWindow *window,
 	{
 	case G_TYPE_STRING:
 		text = cg_window_fetch_string (window, id);
-		npw_value_heap_set_value (values, value, text, NPW_VALID_VALUE);
+		npw_value_set_value (value, text, NPW_VALID_VALUE);
 		g_free (text);
 		break;
 	case G_TYPE_INT:
 		int_value = cg_window_fetch_integer (window, id);
 		sprintf (int_buffer, "%d", int_value);
-		npw_value_heap_set_value (values, value, int_buffer, NPW_VALID_VALUE);
+		npw_value_set_value (value, int_buffer, NPW_VALID_VALUE);
 		break;
 	case G_TYPE_BOOLEAN:
-		npw_value_heap_set_value (values, value,
+		npw_value_set_value (value,
 			cg_window_fetch_boolean (window, id) ? "1" : "0", NPW_VALID_VALUE);
 
 		break;
@@ -269,10 +269,10 @@ cg_window_validate_cc (CgWindow *window)
 	if (priv->validator != NULL) g_object_unref (G_OBJECT (priv->validator));
 	
 	priv->validator = cg_validator_new (
-		glade_xml_get_widget (priv->gxml, "create_button"),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "cc_name")),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "header_file")),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "source_file")), NULL);
+		GTK_WIDGET (gtk_builder_get_object (priv->bxml, "create_button")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "cc_name")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "header_file")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "source_file")), NULL);
 }
 
 static void
@@ -284,13 +284,13 @@ cg_window_validate_go (CgWindow *window)
 	if (priv->validator != NULL) g_object_unref (G_OBJECT (priv->validator));
 	
 	priv->validator = cg_validator_new (
-		glade_xml_get_widget (priv->gxml, "create_button"),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "go_name")),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "go_prefix")),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "go_type")),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "go_func_prefix")),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "header_file")),
-		GTK_ENTRY (glade_xml_get_widget (priv->gxml, "source_file")), NULL);
+		GTK_WIDGET (gtk_builder_get_object (priv->bxml, "create_button")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "go_name")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "go_prefix")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "go_type")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "go_func_prefix")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "header_file")),
+		GTK_ENTRY (gtk_builder_get_object (priv->bxml, "source_file")), NULL);
 }
 
 static void
@@ -351,13 +351,15 @@ cg_window_add_project_toggled_cb (GtkToggleButton *button,
 
 	if (gtk_toggle_button_get_active (button) == FALSE)
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget(
-			priv->gxml, "add_repository"), FALSE);
+		GtkWidget* widget = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "add_repository"));
+		gtk_widget_set_sensitive (widget, FALSE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(widget),
+		                              FALSE);
 	}
 	else
 	{
-		gtk_widget_set_sensitive (glade_xml_get_widget (
-			priv->gxml, "add_repository"), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
+			priv->bxml, "add_repository")), TRUE);
 	}
 }
 
@@ -377,14 +379,14 @@ cg_window_cc_name_changed_cb (GtkEntry *entry,
 	window = CG_WINDOW (user_data);
 	priv = CG_WINDOW_PRIVATE (window);
 
-	file_header = glade_xml_get_widget (priv->gxml, "header_file");
-	file_source = glade_xml_get_widget (priv->gxml, "source_file");
+	file_header = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "header_file"));
+	file_source = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "source_file"));
 
 	str_filebase = cg_window_class_name_to_file_name (
 		gtk_entry_get_text (GTK_ENTRY (entry)));
 
-	str_fileheader = g_strconcat (str_filebase, ".hpp", NULL);
-	str_filesource = g_strconcat (str_filebase, ".cpp", NULL);
+	str_fileheader = g_strconcat (str_filebase, ".h", NULL);
+	str_filesource = g_strconcat (str_filebase, ".cc", NULL);
 	g_free (str_filebase);
 	
 	gtk_entry_set_text (GTK_ENTRY (file_header), str_fileheader);
@@ -419,12 +421,12 @@ cg_window_go_name_changed_cb (GtkEntry *entry,
 	window = CG_WINDOW (user_data);
 	priv = CG_WINDOW_PRIVATE (window);
 	
-	type_prefix = glade_xml_get_widget (priv->gxml, "go_prefix");
-	type_name = glade_xml_get_widget (priv->gxml, "go_type");
-	func_prefix = glade_xml_get_widget (priv->gxml, "go_func_prefix");
+	type_prefix = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "go_prefix"));
+	type_name = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "go_type"));
+	func_prefix = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "go_func_prefix"));
 
-	file_header = glade_xml_get_widget (priv->gxml, "header_file");
-	file_source = glade_xml_get_widget (priv->gxml, "source_file");
+	file_header = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "header_file"));
+	file_source = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "source_file"));
 
 	name = gtk_entry_get_text (GTK_ENTRY (entry));
 	cg_transform_custom_c_type_to_g_type (name, &str_type_prefix,
@@ -470,16 +472,16 @@ cg_window_associate_browse_button (GladeXML *xml,
 #endif
 
 static void
-cg_window_set_glade_xml (CgWindow *window,
-                         GladeXML *xml)
+cg_window_set_builder (CgWindow *window,
+                         GtkBuilder *xml)
 {
 	CgWindowPrivate *priv;
 	priv = CG_WINDOW_PRIVATE (window);
 
-	priv->gxml = xml;
-	g_object_ref (priv->gxml);
+	priv->bxml = xml;
+	g_object_ref (priv->bxml);
 
-	priv->window = glade_xml_get_widget (priv->gxml, "classgen_main");
+	priv->window = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "classgen_main"));
 
 #if 0
 	cg_window_associate_browse_button (priv->gxml, "browse_header",
@@ -490,79 +492,79 @@ cg_window_set_glade_xml (CgWindow *window,
 #endif
 
 	priv->editor_cc = cg_element_editor_new (
-		GTK_TREE_VIEW (glade_xml_get_widget (priv->gxml, "cc_elements")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "cc_elements_add")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "cc_elements_remove")),
+		GTK_TREE_VIEW (gtk_builder_get_object (priv->bxml, "cc_elements")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "cc_elements_add")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "cc_elements_remove")),
 		5,
-		"Scope", CG_ELEMENT_EDITOR_COLUMN_LIST, CC_SCOPE_LIST,
-		"Implementation", CG_ELEMENT_EDITOR_COLUMN_LIST, CC_IMPLEMENTATION_LIST,
-		"Type", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Name", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Arguments", CG_ELEMENT_EDITOR_COLUMN_ARGUMENTS);
+		_("Scope"), CG_ELEMENT_EDITOR_COLUMN_LIST, CC_SCOPE_LIST,
+		_("Implementation"), CG_ELEMENT_EDITOR_COLUMN_LIST, CC_IMPLEMENTATION_LIST,
+		_("Type"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Name"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Arguments"), CG_ELEMENT_EDITOR_COLUMN_ARGUMENTS);
 	
 	priv->editor_go_members = cg_element_editor_new (
-		GTK_TREE_VIEW (glade_xml_get_widget (priv->gxml, "go_members")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "go_members_add")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "go_members_remove")),
+		GTK_TREE_VIEW (gtk_builder_get_object (priv->bxml, "go_members")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "go_members_add")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "go_members_remove")),
 		4,
-		"Scope", CG_ELEMENT_EDITOR_COLUMN_LIST, GO_SCOPE_LIST,
-		"Type", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Name", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Arguments", CG_ELEMENT_EDITOR_COLUMN_ARGUMENTS);
+		_("Scope"), CG_ELEMENT_EDITOR_COLUMN_LIST, GO_SCOPE_LIST,
+		_("Type"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Name"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Arguments"), CG_ELEMENT_EDITOR_COLUMN_ARGUMENTS);
 	
 	priv->editor_go_properties = cg_element_editor_new(
-		GTK_TREE_VIEW (glade_xml_get_widget (priv->gxml, "go_properties")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "go_properties_add")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "go_properties_remove")),
+		GTK_TREE_VIEW (gtk_builder_get_object (priv->bxml, "go_properties")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "go_properties_add")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "go_properties_remove")),
 		7,
-		"Name", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Nick", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Blurb", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"GType", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"ParamSpec", CG_ELEMENT_EDITOR_COLUMN_LIST, GO_PARAMSPEC_LIST,
-		"Default", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Flags", CG_ELEMENT_EDITOR_COLUMN_FLAGS, GO_PROPERTY_FLAGS);
+		_("Name"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Nick"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Blurb"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("GType"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("ParamSpec"), CG_ELEMENT_EDITOR_COLUMN_LIST, GO_PARAMSPEC_LIST,
+		_("Default"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Flags"), CG_ELEMENT_EDITOR_COLUMN_FLAGS, GO_PROPERTY_FLAGS);
 	
 	priv->editor_go_signals = cg_element_editor_new(
-		GTK_TREE_VIEW (glade_xml_get_widget (priv->gxml, "go_signals")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "go_signals_add")),
-		GTK_BUTTON (glade_xml_get_widget (priv->gxml, "go_signals_remove")),
+		GTK_TREE_VIEW (gtk_builder_get_object (priv->bxml, "go_signals")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "go_signals_add")),
+		GTK_BUTTON (gtk_builder_get_object (priv->bxml, "go_signals_remove")),
 		5,
-		"Type", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Name", CG_ELEMENT_EDITOR_COLUMN_STRING,
-		"Arguments", CG_ELEMENT_EDITOR_COLUMN_ARGUMENTS, /* Somehow redundant with marshaller, but required for default handler */
-		"Flags", CG_ELEMENT_EDITOR_COLUMN_FLAGS, GO_SIGNAL_FLAGS,
-		"Marshaller", CG_ELEMENT_EDITOR_COLUMN_STRING);
+		_("Type"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Name"), CG_ELEMENT_EDITOR_COLUMN_STRING,
+		_("Arguments"), CG_ELEMENT_EDITOR_COLUMN_ARGUMENTS, /* Somehow redundant with marshaller, but required for default handler */
+		_("Flags"), CG_ELEMENT_EDITOR_COLUMN_FLAGS, GO_SIGNAL_FLAGS,
+		_("Marshaller"), CG_ELEMENT_EDITOR_COLUMN_STRING);
 
 	/* Active item property in glade cannot be set because no GtkTreeModel
 	 * is assigned. */
 	gtk_combo_box_set_active (
-		GTK_COMBO_BOX (glade_xml_get_widget (priv->gxml, "license")), 0);
+		GTK_COMBO_BOX (gtk_builder_get_object (priv->bxml, "license")), 0);
 
 	gtk_combo_box_set_active (
-		GTK_COMBO_BOX (glade_xml_get_widget (priv->gxml, "cc_inheritance")),
+		GTK_COMBO_BOX (gtk_builder_get_object (priv->bxml, "cc_inheritance")),
 		0);
 
 	/* This revalidates the appropriate validator */
 	g_signal_connect (
-		G_OBJECT (glade_xml_get_widget (priv->gxml, "top_notebook")),
+		G_OBJECT (gtk_builder_get_object (priv->bxml, "top_notebook")),
 		"switch-page", G_CALLBACK (cg_window_top_notebook_switch_page_cb),
 		window);
 	
 	g_signal_connect (
-		G_OBJECT (glade_xml_get_widget (priv->gxml, "go_name")), "changed",
+		G_OBJECT (gtk_builder_get_object (priv->bxml, "go_name")), "changed",
 		G_CALLBACK (cg_window_go_name_changed_cb), window);
 
 	g_signal_connect (
-		G_OBJECT (glade_xml_get_widget (priv->gxml, "cc_name")), "changed",
+		G_OBJECT (gtk_builder_get_object (priv->bxml, "cc_name")), "changed",
 		G_CALLBACK (cg_window_cc_name_changed_cb), window);
 
 	g_signal_connect (
-		G_OBJECT (glade_xml_get_widget(priv->gxml, "add_project")), "toggled",
+		G_OBJECT (gtk_builder_get_object (priv->bxml, "add_project")), "toggled",
 		G_CALLBACK (cg_window_add_project_toggled_cb), window);
 
 	cg_window_add_project_toggled_cb (GTK_TOGGLE_BUTTON (
-		glade_xml_get_widget (priv->gxml, "add_project")), window);
+		gtk_builder_get_object (priv->bxml, "add_project")), window);
 
 	/* Selected page is CC */
 	cg_window_validate_cc (window);
@@ -610,12 +612,12 @@ cg_window_go_properties_transform_func (GHashTable *table,
 	cg_transform_string (table, "Blurb");
 
 	cg_transform_guess_paramspec (table, "ParamSpec",
-	                              "Type", GO_PARAMSPEC_LIST[0]);
+	                              "Type", _(GO_PARAMSPEC_LIST[0]));
 
 	cg_transform_flags (table, "Flags", GO_PROPERTY_FLAGS);
 
 	paramspec = g_hash_table_lookup (table, "ParamSpec");
-	if (strcmp (paramspec, "g_param_spec_string") == 0)
+	if (paramspec && (strcmp (paramspec, "g_param_spec_string") == 0))
 		cg_transform_string (table, "Default");
 }
 
@@ -706,7 +708,7 @@ cg_window_init (CgWindow *window)
 	CgWindowPrivate *priv;
 	priv = CG_WINDOW_PRIVATE (window);
 
-	priv->gxml = NULL;
+	priv->bxml = NULL;
 	priv->window = NULL;
 	
 	priv->editor_cc = NULL;
@@ -738,8 +740,8 @@ cg_window_finalize (GObject *object)
 	if (priv->validator != NULL)
 		g_object_unref (G_OBJECT (priv->validator));
 
-	if (priv->gxml != NULL)
-		g_object_unref (G_OBJECT (priv->gxml));
+	if (priv->bxml != NULL)
+		g_object_unref (G_OBJECT (priv->bxml));
 
 	gtk_widget_destroy(priv->window);
 
@@ -762,9 +764,9 @@ cg_window_set_property (GObject *object,
 
 	switch (prop_id)
 	{
-	case PROP_GLADE_XML:
-		cg_window_set_glade_xml (window,
-		                         GLADE_XML (g_value_get_object (value)));
+	case PROP_BUILDER_XML:
+		cg_window_set_builder (window,
+		                         GTK_BUILDER (g_value_get_object (value)));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -788,8 +790,8 @@ cg_window_get_property (GObject *object,
 
 	switch (prop_id)
 	{
-	case PROP_GLADE_XML:
-		g_value_set_object (value, G_OBJECT (priv->gxml));
+	case PROP_BUILDER_XML:
+		g_value_set_object (value, G_OBJECT (priv->bxml));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -810,11 +812,11 @@ cg_window_class_init (CgWindowClass *klass)
 	object_class->get_property = cg_window_get_property;
 
 	g_object_class_install_property (object_class,
-	                                 PROP_GLADE_XML,
-	                                 g_param_spec_object ("glade-xml",
-	                                                      "Glade XML description",
+	                                 PROP_BUILDER_XML,
+	                                 g_param_spec_object ("builder-xml",
+	                                                      "GtkBuilder",
 	                                                      _("XML description of the user interface"),
-	                                                      GLADE_TYPE_XML,
+	                                                      G_TYPE_OBJECT,
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
@@ -849,13 +851,18 @@ cg_window_get_type (void)
 CgWindow *
 cg_window_new (void)
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml = gtk_builder_new();
 	GObject *window;
+	GError* error = NULL;
 
-	gxml = glade_xml_new (GLADE_FILE, NULL, NULL);
-	if (gxml == NULL) return NULL;
-	
-	window = g_object_new (CG_TYPE_WINDOW, "glade-xml", gxml, NULL);
+	if (!gtk_builder_add_from_file (bxml, BUILDER_FILE, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+		return NULL;
+	}
+
+	window = g_object_new (CG_TYPE_WINDOW, "builder-xml", bxml, NULL);
 	return CG_WINDOW (window);
 }
 
@@ -865,7 +872,7 @@ cg_window_get_dialog (CgWindow *window)
 	return GTK_DIALOG (CG_WINDOW_PRIVATE (window)->window);
 }
 
-NPWValueHeap *
+GHashTable *
 cg_window_create_value_heap (CgWindow *window)
 {
 	static const gchar *LICENSES[] = {
@@ -875,7 +882,7 @@ cg_window_create_value_heap (CgWindow *window)
 	};
 
 	CgWindowPrivate *priv;
-	NPWValueHeap *values;
+	GHashTable *values;
 	NPWValue *value;
 	GError *error;
 	gint license_index;
@@ -890,7 +897,7 @@ cg_window_create_value_heap (CgWindow *window)
 	gchar *base_suffix;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	notebook = GTK_NOTEBOOK (glade_xml_get_widget (priv->gxml,
+	notebook = GTK_NOTEBOOK (gtk_builder_get_object (priv->bxml,
 	                                               "top_notebook"));
 
 	values = npw_value_heap_new ();
@@ -934,10 +941,10 @@ cg_window_create_value_heap (CgWindow *window)
 		g_free (text);
 
 		value = npw_value_heap_find_value (values, "BaseTypePrefix");
-		npw_value_heap_set_value (values, value, base_prefix, NPW_VALID_VALUE);
+		npw_value_set_value (value, base_prefix, NPW_VALID_VALUE);
 		
 		value = npw_value_heap_find_value (values, "BaseTypeSuffix");
-		npw_value_heap_set_value (values, value, base_suffix, NPW_VALID_VALUE);
+		npw_value_set_value (value, base_suffix, NPW_VALID_VALUE);
 		
 		g_free (base_prefix);
 		g_free (base_suffix);
@@ -1002,17 +1009,17 @@ cg_window_create_value_heap (CgWindow *window)
 	license_index = cg_window_fetch_integer (window, "license");
 	value = npw_value_heap_find_value (values, "License");
 
-	npw_value_heap_set_value(values, value, LICENSES[license_index],
+	npw_value_set_value(value, LICENSES[license_index],
 	                         NPW_VALID_VALUE);
 
 	header_file = g_path_get_basename (cg_window_get_header_file (window));
 	source_file = g_path_get_basename (cg_window_get_source_file (window));
 	
 	value = npw_value_heap_find_value (values, "HeaderFile");
-	npw_value_heap_set_value (values, value, header_file, NPW_VALID_VALUE);
+	npw_value_set_value (value, header_file, NPW_VALID_VALUE);
 	
 	value = npw_value_heap_find_value (values, "SourceFile");
-	npw_value_heap_set_value (values, value, source_file, NPW_VALID_VALUE);
+	npw_value_set_value (value, source_file, NPW_VALID_VALUE);
 	
 	g_free (header_file);
 	g_free (source_file);
@@ -1027,7 +1034,7 @@ cg_window_get_header_template (CgWindow *window)
 	GtkNotebook *notebook;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	notebook = GTK_NOTEBOOK (glade_xml_get_widget (priv->gxml,
+	notebook = GTK_NOTEBOOK (gtk_builder_get_object (priv->bxml,
 	                                               "top_notebook"));
 	
 	g_return_val_if_fail (GTK_IS_NOTEBOOK (notebook), NULL);
@@ -1051,7 +1058,7 @@ cg_window_get_header_file(CgWindow *window)
 	GtkEntry *entry;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	entry = GTK_ENTRY (glade_xml_get_widget (priv->gxml, "header_file"));
+	entry = GTK_ENTRY (gtk_builder_get_object (priv->bxml, "header_file"));
 	
 	g_return_val_if_fail (GTK_IS_ENTRY (entry), NULL);
 	return gtk_entry_get_text (entry);
@@ -1064,7 +1071,7 @@ cg_window_get_source_template(CgWindow *window)
 	GtkNotebook *notebook;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	notebook = GTK_NOTEBOOK (glade_xml_get_widget (priv->gxml,
+	notebook = GTK_NOTEBOOK (gtk_builder_get_object (priv->bxml,
 	                                               "top_notebook"));
 	
 	g_return_val_if_fail (GTK_IS_NOTEBOOK (notebook), NULL);
@@ -1088,7 +1095,7 @@ cg_window_get_source_file (CgWindow *window)
 	GtkEntry *entry;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	entry = GTK_ENTRY (glade_xml_get_widget (priv->gxml, "source_file"));
+	entry = GTK_ENTRY (gtk_builder_get_object (priv->bxml, "source_file"));
 	
 	g_return_val_if_fail (GTK_IS_ENTRY (entry), NULL);
 	return gtk_entry_get_text (entry);
@@ -1102,7 +1109,7 @@ cg_window_set_add_to_project (CgWindow *window,
 	GtkCheckButton *button;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	button = GTK_CHECK_BUTTON (glade_xml_get_widget (priv->gxml,
+	button = GTK_CHECK_BUTTON (gtk_builder_get_object (priv->bxml,
 	                                                 "add_project"));
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), enable);
@@ -1116,7 +1123,7 @@ cg_window_set_add_to_repository (CgWindow *window,
 	GtkCheckButton *button;
 
 	priv = CG_WINDOW_PRIVATE (window);
-	button = GTK_CHECK_BUTTON (glade_xml_get_widget (priv->gxml,
+	button = GTK_CHECK_BUTTON (gtk_builder_get_object (priv->bxml,
 	                                                 "add_repository"));
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), enable);
@@ -1135,15 +1142,8 @@ gboolean
 cg_window_get_add_to_repository (CgWindow *window)
 {
 	CgWindowPrivate *priv;
-	GtkWidget *button;
 	priv = CG_WINDOW_PRIVATE (window);
 
-	/* It can happen that the checkbox is checked and then somehow
-	 * disabled (for example by unchecking add to project). In this
-	 * case add to repository should also be FALSE. */
-	button = glade_xml_get_widget (priv->gxml, "add_repository");
-	if (GTK_WIDGET_IS_SENSITIVE(button) == FALSE) return FALSE;
-
 	return cg_window_fetch_boolean (window, "add_repository");
 }
 
@@ -1155,7 +1155,7 @@ cg_window_enable_add_to_project (CgWindow *window,
 	GtkWidget *widget;
 	
 	priv = CG_WINDOW_PRIVATE (window);
-	widget = glade_xml_get_widget (priv->gxml, "add_project");
+	widget = gtk_builder_get_object (priv->bxml, "add_project");
 	
 	gtk_widget_set_sensitive (widget, enable);
 }
@@ -1168,7 +1168,7 @@ cg_window_enable_add_to_repository (CgWindow *window,
 	GtkWidget *widget;
 	
 	priv = CG_WINDOW_PRIVATE (window);
-	widget = glade_xml_get_widget (priv->gxml, "add_repository");
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->bxml, "add_repository"));
 	
 	gtk_widget_set_sensitive (widget, enable);
 }
@@ -1181,7 +1181,7 @@ cg_window_set_author (CgWindow *window,
 	GtkEntry* entry;
 	
 	priv = CG_WINDOW_PRIVATE (window);
-	entry = GTK_ENTRY(glade_xml_get_widget (priv->gxml, "author_name"));
+	entry = GTK_ENTRY(gtk_builder_get_object (priv->bxml, "author_name"));
 	
 	gtk_entry_set_text (entry, author);
 }
@@ -1194,7 +1194,7 @@ cg_window_set_email (CgWindow *window,
 	GtkEntry* entry;
 	
 	priv = CG_WINDOW_PRIVATE (window);
-	entry = GTK_ENTRY(glade_xml_get_widget (priv->gxml, "author_email"));
+	entry = GTK_ENTRY(gtk_builder_get_object (priv->bxml, "author_email"));
 	
 	gtk_entry_set_text (entry, email);
 }
