@@ -15,15 +15,15 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "config.h"
 
 #include <string.h>
 
-#include <gdk/gdkscreen.h>
+#include <gdk/gdk.h>
 
 #include "anjuta-recent-chooser-menu.h"
 
