@@ -23,28 +23,30 @@
  */
 
 #include <config.h>
-#include <glade/glade-xml.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
 #include <libanjuta/interfaces/ianjuta-file-manager.h>
+#include <libanjuta/interfaces/ianjuta-vcs.h>
+#include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
 #include "plugin.h"
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/file-manager.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/file-manager.xml"
 #define ICON_FILE "anjuta-file-manager-plugin-48.png"
-#define FILE_MANAGER_GLADE PACKAGE_DATA_DIR"/glade/file-manager.glade"
-#define FILE_MANAGER_GLADE_ROOT "filemanager_prefs"
+#define FILE_MANAGER_BUILDER PACKAGE_DATA_DIR"/glade/file-manager.ui"
+#define FILE_MANAGER_BUILDER_ROOT "filemanager_prefs"
 
 #define PREF_ROOT "filemanager.root"
 #define PREF_FILTER_BINARY "filemanager.filter.binary"
 #define PREF_FILTER_HIDDEN "filemanager.filter.hidden"
 #define PREF_FILTER_BACKUP "filemanager.filter.backup"
+#define PREF_FILTER_UNVERSIONED "filemanager.filter.unversioned"
 
-#define REGISTER_NOTIFY(key, func) \
-	notify_id = anjuta_preferences_notify_add (file_manager->prefs, \
+#define REGISTER_NOTIFY(key, func, type) \
+	notify_id = anjuta_preferences_notify_add_##type (file_manager->prefs, \
 											   key, func, file_manager, NULL); \
 	file_manager->gconf_notify_ids = g_list_prepend (file_manager->gconf_notify_ids, \
 										   GUINT_TO_POINTER(notify_id));
@@ -60,28 +62,92 @@ struct _ScrollPosition
 };
 
 static void
-on_file_manager_refresh (GtkAction* action, AnjutaFileManager* file_manager)
+on_file_manager_rename (GtkAction* action, AnjutaFileManager* file_manager)
 {	
-	file_view_refresh (file_manager->fv, TRUE);
+	file_view_rename (file_manager->fv);
 }
 
 static GtkActionEntry popup_actions[] = 
 {
 	{
-		"ActionPopupFileManagerRefresh", GTK_STOCK_REFRESH,
-		N_("_Refresh"), NULL, N_("Refresh file manager tree"),
-		G_CALLBACK (on_file_manager_refresh)
+		"ActionPopupFileManagerRename", NULL,
+		N_("_Rename"), NULL, N_("Rename file or directory"),
+		G_CALLBACK (on_file_manager_rename)
 	}
 };
 
 static void
 file_manager_set_default_uri (AnjutaFileManager* file_manager)
 {
-	gchar* uri = 
-		uri = gnome_vfs_get_uri_from_local_path(anjuta_preferences_get (file_manager->prefs, PREF_ROOT));
-	g_object_set (G_OBJECT (file_manager->fv), "base_uri", uri, NULL);
-	file_manager->have_project = FALSE;
-	g_free (uri);
+	GFile *file;	
+	gchar* path = anjuta_preferences_get (file_manager->prefs, PREF_ROOT);
+		
+	if (path)
+	{
+		file = g_file_new_for_path (path);
+		char *uri = g_file_get_uri (file);
+		if (uri)
+			g_object_set (G_OBJECT (file_manager->fv), "base_uri", uri, NULL);
+		file_manager->have_project = FALSE;
+		g_free (uri);
+		g_object_unref (file);
+	}
+	g_free(path);
+}
+
+static IAnjutaVcs*
+get_vcs_plugin(AnjutaFileManager* file_manager, const gchar* root_uri)
+{
+	typedef struct
+	{
+		const gchar* file;
+		const gchar* name;
+	} VcsSystem;
+	VcsSystem vcs_systems[] = {
+		{".svn", "Subversion"},
+		{".git", "Git"},
+		{NULL, NULL}
+	};
+	
+	gint i;
+	const gchar* vcs_system = NULL;
+	IAnjutaVcs* ivcs = NULL;
+	for (i = 0; vcs_systems[i].name != NULL; i++)
+	{
+		gchar* vcs_uri = g_build_filename (root_uri, vcs_systems[i].file, NULL);
+		GFile* vcs_file = g_file_new_for_uri (vcs_uri);
+		if (g_file_query_exists(vcs_file, NULL))
+		{
+			vcs_system = vcs_systems[i].name;
+		}
+		g_free (vcs_uri);
+		g_object_unref (vcs_file);
+		if (vcs_system)
+			break;
+	}
+	
+	if (vcs_system)
+	{
+		/* Load current language editor support plugins */
+		AnjutaPluginManager* plugin_manager = anjuta_shell_get_plugin_manager (ANJUTA_PLUGIN(file_manager)->shell, NULL);
+		GList* plugin_descs = anjuta_plugin_manager_query (plugin_manager,
+														   "Anjuta Plugin",
+														   "Interfaces",
+														   "IAnjutaVcs",
+														   "Vcs",
+														   "System",
+														   vcs_system, NULL);
+		if (plugin_descs)
+		{
+			gchar* plugin_id;
+			anjuta_plugin_description_get_string (plugin_descs->data, "Anjuta Plugin", "Location",
+													  &plugin_id);
+			ivcs = IANJUTA_VCS(anjuta_plugin_manager_get_plugin_by_id (plugin_manager,
+																	   plugin_id));
+			g_list_free (plugin_descs);
+		}
+	}
+	return ivcs;
 }
 
 static void
@@ -96,13 +162,19 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	if (root_uri)
 	{
 		g_object_set (G_OBJECT(file_manager->fv), "base_uri", root_uri, NULL);
-		file_view_refresh (file_manager->fv, FALSE);
+		g_object_set_data (G_OBJECT(file_manager->fv), "__ivcs",
+						   get_vcs_plugin (file_manager,
+										   root_uri));
+		
+		file_view_refresh (file_manager->fv);
 		file_manager->have_project = TRUE;
 	}
 	else
 	{
+		g_object_set_data (G_OBJECT(file_manager->fv), "__ivcs",
+						   NULL);
 		file_manager_set_default_uri (file_manager);
-		file_view_refresh (file_manager->fv, FALSE);
+		file_view_refresh (file_manager->fv);
 	}
 }
 
@@ -112,78 +184,93 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 {
 	AnjutaFileManager* file_manager = (AnjutaFileManager*) plugin;
 	file_manager_set_default_uri (file_manager);
-	file_view_refresh (file_manager->fv, FALSE);
+	file_view_refresh (file_manager->fv);
 }
 
 static void
-on_file_view_current_uri_changed (AnjutaFileView* view, gchar* uri,
-								  AnjutaFileManager* file_manager)
+on_file_view_current_file_changed (AnjutaFileView* view, GFile* file,
+								   AnjutaFileManager* file_manager)
 {
-	if (uri)
+	if (file)
 	{
 		GValue* value;
 		value = g_new0 (GValue, 1);
-		g_value_init (value, G_TYPE_STRING);
-		g_value_take_string (value, uri);
+		g_value_init (value, G_TYPE_FILE);
+		g_value_set_object (value, file);
 		anjuta_shell_add_value (ANJUTA_PLUGIN (file_manager)->shell,
-								"file_manager_current_uri", value, NULL);
+								IANJUTA_FILE_MANAGER_SELECTED_FILE, value, NULL);
+		g_value_unset (value);
 	}
 	else
 	{
 		anjuta_shell_remove_value (ANJUTA_PLUGIN(file_manager)->shell,
-								   "file_manager_current_uri", NULL);		
+								   IANJUTA_FILE_MANAGER_SELECTED_FILE, NULL);		
 	}
 }
 
 static void
-on_file_view_open_file (AnjutaFileView* view, const char *uri,
+on_file_view_open_file (AnjutaFileView* view, GFile* file,
 						AnjutaFileManager* file_manager)
 {
 	IAnjutaFileLoader *loader;
-	g_return_if_fail (uri != NULL);
+	g_return_if_fail (file != NULL);
 	loader = anjuta_shell_get_interface (ANJUTA_PLUGIN (file_manager)->shell,
 										 IAnjutaFileLoader, NULL);
 	g_return_if_fail (loader != NULL);
 		
-	ianjuta_file_loader_load (loader, uri, FALSE, NULL);
+	ianjuta_file_loader_load (loader, file, FALSE, NULL);
 }
 
 static void
-on_file_view_show_popup_menu (AnjutaFileView* view, const gchar* uri,
-							  gboolean is_dir,guint button,
+on_file_view_show_popup_menu (AnjutaFileView* view, GFile* file,
+							  gboolean is_dir, guint button,
 							  guint32 time, AnjutaFileManager* file_manager)
 {
 	GtkWidget *popup;
+	GtkWidget *rename;
 	AnjutaUI* ui = anjuta_shell_get_ui (ANJUTA_PLUGIN(file_manager)->shell, 
 										NULL);
 	popup = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui),
 									   "/PopupFileManager");
+	rename = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui),
+									   "/PopupFileManager/PopupFileManagerRename");
+	/* TODO */
+	gtk_widget_hide (rename);
+	
 	g_return_if_fail (GTK_IS_WIDGET (popup));
 	gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL, button, time);
 }
 
 static void 
-on_gconf_notify(GConfClient *gclient, guint cnxn_id,
-				GConfEntry *entry, gpointer user_data)
+on_notify_root(AnjutaPreferences* prefs,
+                         const gchar* key,
+                         const gchar* value,
+                         gpointer user_data)
 {
 	AnjutaFileManager* file_manager = (AnjutaFileManager*) user_data;
-	GtkTreeModel* model = gtk_tree_view_get_model (GTK_TREE_VIEW (file_manager->fv));
-	
-	g_object_set (G_OBJECT (model),
-				  "filter_binary", anjuta_preferences_get_int (file_manager->prefs, PREF_FILTER_BINARY),
-				  "filter_hidden", anjuta_preferences_get_int (file_manager->prefs, PREF_FILTER_HIDDEN),
-				  "filter_backup", anjuta_preferences_get_int (file_manager->prefs, PREF_FILTER_BACKUP), NULL);				  
-	
 	if (!file_manager->have_project)
 	{
 		file_manager_set_default_uri (file_manager);
-		file_view_refresh (file_manager->fv, FALSE);
-	}
-	else
-	{
-		file_view_refresh (file_manager->fv, TRUE);
+		file_view_refresh (file_manager->fv);
 	}
+}
+
+static void 
+on_notify(AnjutaPreferences* prefs,
+          const gchar* key,
+          gboolean value,
+          gpointer user_data)
+{
+	AnjutaFileManager* file_manager = (AnjutaFileManager*) user_data;
+	GtkTreeModel* sort_model = gtk_tree_view_get_model (GTK_TREE_VIEW (file_manager->fv));
+	GtkTreeModel* file_model = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT(sort_model));
 	
+	g_object_set (G_OBJECT (file_model),
+				  "filter_binary", anjuta_preferences_get_bool (file_manager->prefs, PREF_FILTER_BINARY),
+				  "filter_hidden", anjuta_preferences_get_bool (file_manager->prefs, PREF_FILTER_HIDDEN),
+				  "filter_backup", anjuta_preferences_get_bool (file_manager->prefs, PREF_FILTER_BACKUP),
+				  "filter_unversioned", anjuta_preferences_get_bool (file_manager->prefs, PREF_FILTER_UNVERSIONED), NULL);
+	file_view_refresh (file_manager->fv);
 }
 
 static gboolean
@@ -193,7 +280,7 @@ file_manager_activate (AnjutaPlugin *plugin)
 	AnjutaFileManager *file_manager;
 	gint notify_id;
 	
-	DEBUG_PRINT ("AnjutaFileManager: Activating AnjutaFileManager plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaFileManager: Activating AnjutaFileManager plugin ...");
 	file_manager = (AnjutaFileManager*) plugin;
 
 	file_manager->prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
@@ -224,11 +311,11 @@ file_manager_activate (AnjutaPlugin *plugin)
 					  G_CALLBACK (on_file_view_open_file), file_manager);
 	g_signal_connect (G_OBJECT(file_manager->fv), "show-popup-menu",
 					  G_CALLBACK (on_file_view_show_popup_menu), file_manager);
-	g_signal_connect (G_OBJECT(file_manager->fv), "current-uri-changed",
-					  G_CALLBACK (on_file_view_current_uri_changed),
+	g_signal_connect (G_OBJECT(file_manager->fv), "current-file-changed",
+					  G_CALLBACK (on_file_view_current_file_changed),
 					  file_manager);
 	file_manager_set_default_uri (file_manager);
-	file_view_refresh (file_manager->fv, FALSE);
+	file_view_refresh (file_manager->fv);
 	
 	gtk_container_add (GTK_CONTAINER (file_manager->sw), 
 					   GTK_WIDGET (file_manager->fv));
@@ -241,16 +328,17 @@ file_manager_activate (AnjutaPlugin *plugin)
 							 ANJUTA_SHELL_PLACEMENT_LEFT, NULL);
 	
 	file_manager->root_watch_id =
-		anjuta_plugin_add_watch (plugin, "project_root_uri",
+		anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 								 project_root_added,
 								 project_root_removed, NULL);
 	
 	
-	REGISTER_NOTIFY (PREF_ROOT, on_gconf_notify);
-	REGISTER_NOTIFY (PREF_FILTER_BINARY, on_gconf_notify);
-	REGISTER_NOTIFY (PREF_FILTER_BACKUP, on_gconf_notify);
-	REGISTER_NOTIFY (PREF_FILTER_HIDDEN, on_gconf_notify);
-	on_gconf_notify (NULL, 0, NULL, file_manager);
+	REGISTER_NOTIFY (PREF_ROOT, on_notify_root, string);
+	REGISTER_NOTIFY (PREF_FILTER_BINARY, on_notify, bool);
+	REGISTER_NOTIFY (PREF_FILTER_BACKUP, on_notify, bool);
+	REGISTER_NOTIFY (PREF_FILTER_HIDDEN, on_notify, bool);
+	REGISTER_NOTIFY (PREF_FILTER_UNVERSIONED, on_notify, bool);
+	on_notify (anjuta_preferences_default(), NULL, FALSE, file_manager);
 	
 	return TRUE;
 }
@@ -261,7 +349,7 @@ file_manager_deactivate (AnjutaPlugin *plugin)
 	AnjutaUI *ui;
 	AnjutaFileManager *file_manager;
 
-	DEBUG_PRINT ("AnjutaFileManager: Dectivating AnjutaFileManager plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaFileManager: Dectivating AnjutaFileManager plugin ...");
 	
 	file_manager = (AnjutaFileManager*) plugin;
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
@@ -331,12 +419,12 @@ ifile_manager_set_root (IAnjutaFileManager *ifile_manager, const gchar *root,
 
 static void
 ifile_manager_set_selected (IAnjutaFileManager *file_manager,
-							const gchar *root, GError **err)
+							GFile* selected, GError **err)
 {
 	/* TODO */
 }
 
-static gchar*
+static GFile*
 ifile_manager_get_selected (IAnjutaFileManager *ifile_manager, GError **err)
 {
 	AnjutaFileManager* file_manager = (AnjutaFileManager*) ifile_manager;
@@ -356,11 +444,16 @@ ipreferences_merge (IAnjutaPreferences* ipref,
 					AnjutaPreferences* prefs,
 					GError** e)
 {
-	GladeXML* gxml;
-	
-	gxml = glade_xml_new (FILE_MANAGER_GLADE, FILE_MANAGER_GLADE_ROOT, NULL);
-	
-	anjuta_preferences_add_page (prefs, gxml, FILE_MANAGER_GLADE_ROOT, _("File Manager"),
+	GError* error = NULL;
+	GtkBuilder* bxml = gtk_builder_new ();
+
+	if (!gtk_builder_add_from_file (bxml, FILE_MANAGER_BUILDER, &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
+
+	anjuta_preferences_add_from_builder (prefs, bxml, FILE_MANAGER_BUILDER_ROOT, _("File Manager"),
 								 ICON_FILE);
 }
 
